@@ -1,5 +1,3 @@
-/* $Id: prockernel.c,v 1.13.2.1 1999/05/27 19:24:19 martin Exp $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -21,10 +19,13 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/prockernel.h>
 
+#include "glibtop_private.h"
+
 static const unsigned long _glibtop_sysdeps_proc_kernel =
 (1L << GLIBTOP_PROC_KERNEL_K_FLAGS) + (1L << GLIBTOP_PROC_KERNEL_MIN_FLT) +
 (1L << GLIBTOP_PROC_KERNEL_MAJ_FLT) + (1L << GLIBTOP_PROC_KERNEL_CMIN_FLT) +
@@ -34,7 +35,7 @@ static const unsigned long _glibtop_sysdeps_proc_kernel =
 /* Init function. */
 
 void
-glibtop_init_proc_kernel_s (glibtop *server)
+_glibtop_init_proc_kernel_s (glibtop *server)
 {
 	server->sysdeps.proc_kernel = _glibtop_sysdeps_proc_kernel;
 }
@@ -45,12 +46,10 @@ void
 glibtop_get_proc_kernel_s (glibtop *server, glibtop_proc_kernel *buf, pid_t pid)
 {
 	char buffer [BUFSIZ], *p;
-	
-	glibtop_init_s (&server, GLIBTOP_SYSDEPS_PROC_KERNEL, 0);
 
 	memset (buf, 0, sizeof (glibtop_proc_kernel));
 
-	if (proc_stat_to_buffer (buffer, pid))
+	if (proc_stat_to_buffer(buffer, sizeof buffer, pid))
 		return;
 
 	p = proc_stat_after_cmd (buffer);
@@ -58,20 +57,20 @@ glibtop_get_proc_kernel_s (glibtop *server, glibtop_proc_kernel *buf, pid_t pid)
 
 	p = skip_multiple_token (p, 6);
 
-	buf->k_flags   = strtoul (p, &p, 0);
-	buf->min_flt   = strtoul (p, &p, 0);
-	buf->cmin_flt  = strtoul (p, &p, 0);
-	buf->maj_flt   = strtoul (p, &p, 0);
-	buf->cmaj_flt  = strtoul (p, &p, 0);
+	buf->k_flags   = strtoull (p, &p, 0);
+	buf->min_flt   = strtoull (p, &p, 0);
+	buf->cmin_flt  = strtoull (p, &p, 0);
+	buf->maj_flt   = strtoull (p, &p, 0);
+	buf->cmaj_flt  = strtoull (p, &p, 0);
 
 	p = skip_multiple_token (p, 15);
 
-	buf->kstk_esp = strtoul (p, &p, 0);
-	buf->kstk_eip = strtoul (p, &p, 0);
-	
+	buf->kstk_esp = strtoull (p, &p, 0);
+	buf->kstk_eip = strtoull (p, &p, 0);
+
 	p = skip_multiple_token (p, 4);
-	
-	buf->nwchan = strtoul (p, &p, 0);
+
+	buf->nwchan = strtoull (p, &p, 0);
 
 	buf->flags = _glibtop_sysdeps_proc_kernel;
 }
